==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/sql_history/translations/sql_history_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>Připravuje se databáze s historií...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>Otevření databáze se nezdařilo. Hlášení o chybě:
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation>Zdá se, že vaše knihovna Qt neposkytuje podporu pro vybranou databázi. Nainstalujte, prosím, Qt s přídavným modulem %1.</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>Kopíruje se soubor s historií do nového umístění: %1...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>Nelze kopírovat soubor s historií do nového umístění. Prověřte, zda není disk plný.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>Nelze otevřít databázi: %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>Soubor s historií je poškozený. Provádí se obnova...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>Obnova dokončena.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>Obnova se nezdařila: %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>Soubor s historií je zastaralý. Provádí se zavedení...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>Zavedení dokončeno.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>Kopírování dokončeno.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>Žádná chyba.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>Spustitelný soubor pro sqlite3 nenalezen.</translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>Neplatné volání obnovovacího skriptu.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>Nelze přečíst poškozenou databázi.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>Nelze vytvořit soubor se zálohou. Disk je zřejmě plný.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>Obnovovací skript nenalezen nebo není spustitelný.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>Neznámá chyba během obnovování databáze.</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/sql_history/translations/sql_history_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>Připravuje se databáze s historií...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>Otevření databáze se nezdařilo. Hlášení o chybě:
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation>Zdá se, že vaše knihovna Qt neposkytuje podporu pro vybranou databázi. Nainstalujte, prosím, Qt s přídavným modulem %1.</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>Kopíruje se soubor s historií do nového umístění: %1...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>Nelze kopírovat soubor s historií do nového umístění. Prověřte, zda není disk plný.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>Nelze otevřít databázi: %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>Soubor s historií je poškozený. Provádí se obnova...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>Obnova dokončena.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>Obnova se nezdařila: %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>Soubor s historií je zastaralý. Provádí se zavedení...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>Zavedení dokončeno.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>Kopírování dokončeno.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>Žádná chyba.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>Spustitelný soubor pro sqlite3 nenalezen.</translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>Neplatné volání obnovovacího skriptu.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>Nelze přečíst poškozenou databázi.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>Nelze vytvořit soubor se zálohou. Disk je zřejmě plný.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>Obnovovací skript nenalezen nebo není spustitelný.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>Neznámá chyba během obnovování databáze.</translation>
    </message>
</context>
</TS>
